@@ -5,7 +5,7 @@
 @license: LGPLv3+
 '''
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 import gtk, gobject
 import gtkdialogs
@@ -1434,6 +1434,8 @@ class MainWindow:
 
         hpaned.pack1(vbox1, False, True)
 
+        editbox.navigation_pane = vbox1
+
         ## 编辑区
         import webkitedit
         scrolledwindow2 = gtk.ScrolledWindow()
@@ -1456,7 +1458,6 @@ class MainWindow:
 
         if editfile:
             edit.lastDir = os.path.dirname(editfile)
-            edit.editfile = editfile
             edit.title = os.path.basename(editfile)
             self.add_recent(editfile)
             pass
@@ -1713,7 +1714,11 @@ class MainWindow:
 
     def on_open(self, *args):
         #-print 'on_open:'
-        filename = gtkdialogs.open(title=_('Open'), name_mimes={_("Html Document"):"text/html"})
+        filename = gtkdialogs.open(title=_('Open'),
+                name_mimes=[
+                    [_("Html Document"), "text/html"],
+                    [_("MS Doc Document"), "application/msword"],
+                    ])
         if filename and os.access(filename, os.R_OK):
             self.open(filename)
             pass
@@ -1730,7 +1735,7 @@ class MainWindow:
             #current_name = ''
             current_name = get_doctitle(html)
             filename = gtkdialogs.save(title=_('Save'), 
-                    name_mimes={_("Html Document"):"text/html"},
+                    name_mimes=[[_("Html Document"), "text/html"]],
                     current_name=current_name,)
             if filename and not '.' in os.path.basename(filename):
                 filename = filename + '.html'
@@ -1761,7 +1766,7 @@ class MainWindow:
         #current_name = ''
         current_name = get_doctitle(html)
         filename = gtkdialogs.save(title=_('Save As'), 
-                name_mimes={_("Html Document"):"text/html"},
+                name_mimes=[[_("Html Document"), "text/html"]],
                 current_name=current_name, folder=self.edit.lastDir,)
         if filename and not '.' in os.path.basename(filename):
             filename = filename + '.html'
@@ -1893,7 +1898,18 @@ class MainWindow:
     def view_sourceview(self, *args):
         #-print 'view_sourceview:'
         self.window.present()
-        self.edit.do_html_view()
+        ## 源码模式隐藏导航栏
+        #@NOTE 执行顺序和 idle_add 是为了避免闪烁
+        if not self.edit.get_view_source_mode():
+            ## 先转到源码模式，再 idle_add 隐藏导航条，以便显示变化平滑
+            self.edit.toggle_html_view()
+            gobject.idle_add( self.editbox.navigation_pane.hide )
+            pass
+        else:
+            ## 先显示导航条，再 idle_add 转为所见所得模式，以便显示变化平滑
+            self.editbox.navigation_pane.show_all()
+            gobject.idle_add( self.edit.toggle_html_view )
+            pass
         #self.edit.do_bodyhtml_view()
         pass
 
@@ -1905,7 +1921,7 @@ class MainWindow:
 
     def do_insertimage(self, *args):
         #-print 'do_insertimage:'
-        src = gtkdialogs.open(title=_('InsertImage'), name_mimes={_("Image Files"):"image/*"})
+        src = gtkdialogs.open(title=_('InsertImage'), name_mimes=[[_("Image Files"), "image/*"]])
         if src:
             self.edit.do_insertimage(src)
         pass
@@ -2362,6 +2378,12 @@ def main():
         i = os.path.abspath(i)
         edit.open(i)
         pass
+    ## 处理 Gtk 图标主题
+    settings = gtk.settings_get_default( )
+    if settings.get_property( 'gtk-icon-theme-name' ) == 'hicolor':
+        settings.set_property( 'gtk-icon-theme-name', 'Tango')
+        pass
+    ##
     gtk.gdk.threads_enter()
     gtk.main()
     gtk.gdk.threads_leave()
